import secrets
from datetime import datetime, timezone

CROCKFORD_BASE32 = '0123456789ABCDEFGHJKMNPQRSTVWXYZ'


def new():
    """
    Generate a ULID (Universally Unique Lexicographically Sortable Identifier).

    Steps:
        1. Get the current timestamp in milliseconds
        2. Convert the timestamp to a 50-bit binary string
        3. Generate 80 random bits for uniqueness
        4. Convert the 130-bit binary string into a 26-character ULID using Base32 encoding
    """
    current_timestamp = int(datetime.now(timezone.utc).timestamp() * 1000)
    epoch_bits = '{0:050b}'.format(current_timestamp)
    random_bits = '{0:080b}'.format(secrets.randbits(80))
    bits = epoch_bits + random_bits
    return ''.join(CROCKFORD_BASE32[int(bits[i: i + 5], base=2)] for i in range(0, 130, 5))



import re

from setuptools import setup


def ulid_version():
    with open('ulid/__init__.py') as f:
        return re.search("__version__ = ['\"]([^'\"]+)['\"]", f.read()).group(1)


VERSION = ulid_version()
with open('README.md', encoding='utf-8') as file:
    DESCRIPTION = file.read()

setup(
    name='simple-ulid',
    version=VERSION,
    python_requires='>=3.6',
    author='Ali RajabNezhad',
    author_email='alirn1997@gmail.com',
    url='https://github.com/alirn76/ulid',
    description='Universally Unique Lexicographically Sortable Identifier',
    long_description=DESCRIPTION,
    long_description_content_type='text/markdown',
    include_package_data=True,
    license='MIT',
    classifiers=[
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
        'Programming Language :: Python :: 3.14',
    ],
)
